FlutterKnobPainter class

A CustomPainter responsible for rendering the visual appearance of the knob.

It draws the outer ring, the inner knob, a marker indicating the current value, and optionally value labels around the knob.

Inheritance

Constructors

FlutterKnobPainter({required double value, required double minValue, required double maxValue, required Color markerColor, required Gradient outerRingGradient, required Gradient innerKnobGradient, required double startAngle, required double endAngle, required double rotation, required bool showLabels})
Creates a FlutterKnobPainter to render the knob widget.

Properties

endAngle double
The ending angle (in radians) for the knob’s rotation.
final
hashCode int
The hash code for this object.
no setterinherited
innerKnobGradient Gradient
The gradient used for the inner circle of the knob.
final
markerColor Color
The color used to paint the value marker.
final
maxValue double
The maximum possible value for the knob.
final
minValue double
The minimum possible value for the knob.
final
outerRingGradient Gradient
The gradient used for the outer ring of the knob.
final
rotation double
The maximum rotation value that maps to the full sweep of the knob.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
showLabels bool
Whether to show value labels around the knob.
final
startAngle double
The starting angle (in radians) for the knob’s rotation.
final
value double
Current value to be represented by the knob.
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant FlutterKnobPainter oldDelegate) bool
Determines whether the knob should be repainted.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited